package com.ruoyi.framework.recovery.mapper;

import java.util.List;
import com.ruoyi.framework.recovery.domain.RecStores;

/**
 * 回收发售门店Mapper接口
 * 
 * @author jin
 * @date 2024-11-16
 */
public interface RecStoresMapper 
{
    /**
     * 查询回收发售门店
     * 
     * @param id 回收发售门店主键
     * @return 回收发售门店
     */
    public RecStores selectRecStoresById(Long id);

    /**
     * 查询回收发售门店列表
     * 
     * @param recStores 回收发售门店
     * @return 回收发售门店集合
     */
    public List<RecStores> selectRecStoresList(RecStores recStores);

    /**
     * 新增回收发售门店
     * 
     * @param recStores 回收发售门店
     * @return 结果
     */
    public int insertRecStores(RecStores recStores);

    /**
     * 修改回收发售门店
     * 
     * @param recStores 回收发售门店
     * @return 结果
     */
    public int updateRecStores(RecStores recStores);

    /**
     * 删除回收发售门店
     * 
     * @param id 回收发售门店主键
     * @return 结果
     */
    public int deleteRecStoresById(Long id);

    /**
     * 批量删除回收发售门店
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecStoresByIds(Long[] ids);
}
